@@ -119,7 +119,7 @@ class Exceptions:
 
 class LambdaClient:
     """
-    [Lambda.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/lambda.html#Lambda.Client)
+    [Lambda.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.47/reference/services/lambda.html#Lambda.Client)
     """
 
     exceptions: Exceptions
@@ -135,7 +135,7 @@ class LambdaClient:
         RevisionId: str = None,
     ) -> AddLayerVersionPermissionResponseTypeDef:
         """
-        [Client.add_layer_version_permission documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/lambda.html#Lambda.Client.add_layer_version_permission)
+        [Client.add_layer_version_permission documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.47/reference/services/lambda.html#Lambda.Client.add_layer_version_permission)
         """
 
     def add_permission(
@@ -151,12 +151,12 @@ class LambdaClient:
         RevisionId: str = None,
     ) -> AddPermissionResponseTypeDef:
         """
-        [Client.add_permission documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/lambda.html#Lambda.Client.add_permission)
+        [Client.add_permission documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.47/reference/services/lambda.html#Lambda.Client.add_permission)
         """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/lambda.html#Lambda.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.47/reference/services/lambda.html#Lambda.Client.can_paginate)
         """
 
     def create_alias(
@@ -168,7 +168,7 @@ class LambdaClient:
         RoutingConfig: "AliasRoutingConfigurationTypeDef" = None,
     ) -> "AliasConfigurationTypeDef":
         """
-        [Client.create_alias documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/lambda.html#Lambda.Client.create_alias)
+        [Client.create_alias documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.47/reference/services/lambda.html#Lambda.Client.create_alias)
         """
 
     def create_event_source_mapping(
@@ -185,9 +185,10 @@ class LambdaClient:
         MaximumRecordAgeInSeconds: int = None,
         BisectBatchOnFunctionError: bool = None,
         MaximumRetryAttempts: int = None,
+        Topics: List[str] = None,
     ) -> "EventSourceMappingConfigurationTypeDef":
         """
-        [Client.create_event_source_mapping documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/lambda.html#Lambda.Client.create_event_source_mapping)
+        [Client.create_event_source_mapping documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.47/reference/services/lambda.html#Lambda.Client.create_event_source_mapping)
         """
 
     def create_function(
@@ -201,6 +202,7 @@ class LambdaClient:
             "nodejs10.x",
             "nodejs12.x",
             "java8",
+            "java8.al2",
             "java11",
             "python2.7",
             "python3.6",
@@ -215,6 +217,7 @@ class LambdaClient:
             "ruby2.5",
             "ruby2.7",
             "provided",
+            "provided.al2",
         ],
         Role: str,
         Handler: str,
@@ -233,42 +236,42 @@ class LambdaClient:
         FileSystemConfigs: List["FileSystemConfigTypeDef"] = None,
     ) -> "FunctionConfigurationTypeDef":
         """
-        [Client.create_function documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/lambda.html#Lambda.Client.create_function)
+        [Client.create_function documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.47/reference/services/lambda.html#Lambda.Client.create_function)
         """
 
     def delete_alias(self, FunctionName: str, Name: str) -> None:
         """
-        [Client.delete_alias documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/lambda.html#Lambda.Client.delete_alias)
+        [Client.delete_alias documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.47/reference/services/lambda.html#Lambda.Client.delete_alias)
         """
 
     def delete_event_source_mapping(self, UUID: str) -> "EventSourceMappingConfigurationTypeDef":
         """
-        [Client.delete_event_source_mapping documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/lambda.html#Lambda.Client.delete_event_source_mapping)
+        [Client.delete_event_source_mapping documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.47/reference/services/lambda.html#Lambda.Client.delete_event_source_mapping)
         """
 
     def delete_function(self, FunctionName: str, Qualifier: str = None) -> None:
         """
-        [Client.delete_function documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/lambda.html#Lambda.Client.delete_function)
+        [Client.delete_function documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.47/reference/services/lambda.html#Lambda.Client.delete_function)
         """
 
     def delete_function_concurrency(self, FunctionName: str) -> None:
         """
-        [Client.delete_function_concurrency documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/lambda.html#Lambda.Client.delete_function_concurrency)
+        [Client.delete_function_concurrency documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.47/reference/services/lambda.html#Lambda.Client.delete_function_concurrency)
         """
 
     def delete_function_event_invoke_config(self, FunctionName: str, Qualifier: str = None) -> None:
         """
-        [Client.delete_function_event_invoke_config documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/lambda.html#Lambda.Client.delete_function_event_invoke_config)
+        [Client.delete_function_event_invoke_config documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.47/reference/services/lambda.html#Lambda.Client.delete_function_event_invoke_config)
         """
 
     def delete_layer_version(self, LayerName: str, VersionNumber: int) -> None:
         """
-        [Client.delete_layer_version documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/lambda.html#Lambda.Client.delete_layer_version)
+        [Client.delete_layer_version documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.47/reference/services/lambda.html#Lambda.Client.delete_layer_version)
         """
 
     def delete_provisioned_concurrency_config(self, FunctionName: str, Qualifier: str) -> None:
         """
-        [Client.delete_provisioned_concurrency_config documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/lambda.html#Lambda.Client.delete_provisioned_concurrency_config)
+        [Client.delete_provisioned_concurrency_config documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.47/reference/services/lambda.html#Lambda.Client.delete_provisioned_concurrency_config)
         """
 
     def generate_presigned_url(
@@ -279,77 +282,77 @@ class LambdaClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/lambda.html#Lambda.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.47/reference/services/lambda.html#Lambda.Client.generate_presigned_url)
         """
 
     def get_account_settings(self) -> GetAccountSettingsResponseTypeDef:
         """
-        [Client.get_account_settings documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/lambda.html#Lambda.Client.get_account_settings)
+        [Client.get_account_settings documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.47/reference/services/lambda.html#Lambda.Client.get_account_settings)
         """
 
     def get_alias(self, FunctionName: str, Name: str) -> "AliasConfigurationTypeDef":
         """
-        [Client.get_alias documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/lambda.html#Lambda.Client.get_alias)
+        [Client.get_alias documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.47/reference/services/lambda.html#Lambda.Client.get_alias)
         """
 
     def get_event_source_mapping(self, UUID: str) -> "EventSourceMappingConfigurationTypeDef":
         """
-        [Client.get_event_source_mapping documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/lambda.html#Lambda.Client.get_event_source_mapping)
+        [Client.get_event_source_mapping documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.47/reference/services/lambda.html#Lambda.Client.get_event_source_mapping)
         """
 
     def get_function(self, FunctionName: str, Qualifier: str = None) -> GetFunctionResponseTypeDef:
         """
-        [Client.get_function documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/lambda.html#Lambda.Client.get_function)
+        [Client.get_function documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.47/reference/services/lambda.html#Lambda.Client.get_function)
         """
 
     def get_function_concurrency(self, FunctionName: str) -> GetFunctionConcurrencyResponseTypeDef:
         """
-        [Client.get_function_concurrency documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/lambda.html#Lambda.Client.get_function_concurrency)
+        [Client.get_function_concurrency documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.47/reference/services/lambda.html#Lambda.Client.get_function_concurrency)
         """
 
     def get_function_configuration(
         self, FunctionName: str, Qualifier: str = None
     ) -> "FunctionConfigurationTypeDef":
         """
-        [Client.get_function_configuration documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/lambda.html#Lambda.Client.get_function_configuration)
+        [Client.get_function_configuration documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.47/reference/services/lambda.html#Lambda.Client.get_function_configuration)
         """
 
     def get_function_event_invoke_config(
         self, FunctionName: str, Qualifier: str = None
     ) -> "FunctionEventInvokeConfigTypeDef":
         """
-        [Client.get_function_event_invoke_config documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/lambda.html#Lambda.Client.get_function_event_invoke_config)
+        [Client.get_function_event_invoke_config documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.47/reference/services/lambda.html#Lambda.Client.get_function_event_invoke_config)
         """
 
     def get_layer_version(
         self, LayerName: str, VersionNumber: int
     ) -> GetLayerVersionResponseTypeDef:
         """
-        [Client.get_layer_version documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/lambda.html#Lambda.Client.get_layer_version)
+        [Client.get_layer_version documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.47/reference/services/lambda.html#Lambda.Client.get_layer_version)
         """
 
     def get_layer_version_by_arn(self, Arn: str) -> GetLayerVersionResponseTypeDef:
         """
-        [Client.get_layer_version_by_arn documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/lambda.html#Lambda.Client.get_layer_version_by_arn)
+        [Client.get_layer_version_by_arn documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.47/reference/services/lambda.html#Lambda.Client.get_layer_version_by_arn)
         """
 
     def get_layer_version_policy(
         self, LayerName: str, VersionNumber: int
     ) -> GetLayerVersionPolicyResponseTypeDef:
         """
-        [Client.get_layer_version_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/lambda.html#Lambda.Client.get_layer_version_policy)
+        [Client.get_layer_version_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.47/reference/services/lambda.html#Lambda.Client.get_layer_version_policy)
         """
 
     def get_policy(self, FunctionName: str, Qualifier: str = None) -> GetPolicyResponseTypeDef:
         """
-        [Client.get_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/lambda.html#Lambda.Client.get_policy)
+        [Client.get_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.47/reference/services/lambda.html#Lambda.Client.get_policy)
         """
 
     def get_provisioned_concurrency_config(
         self, FunctionName: str, Qualifier: str
     ) -> GetProvisionedConcurrencyConfigResponseTypeDef:
         """
-        [Client.get_provisioned_concurrency_config documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/lambda.html#Lambda.Client.get_provisioned_concurrency_config)
+        [Client.get_provisioned_concurrency_config documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.47/reference/services/lambda.html#Lambda.Client.get_provisioned_concurrency_config)
         """
 
     def invoke(
@@ -362,14 +365,14 @@ class LambdaClient:
         Qualifier: str = None,
     ) -> InvocationResponseTypeDef:
         """
-        [Client.invoke documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/lambda.html#Lambda.Client.invoke)
+        [Client.invoke documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.47/reference/services/lambda.html#Lambda.Client.invoke)
         """
 
     def invoke_async(
         self, FunctionName: str, InvokeArgs: Union[bytes, IO[bytes]]
     ) -> InvokeAsyncResponseTypeDef:
         """
-        [Client.invoke_async documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/lambda.html#Lambda.Client.invoke_async)
+        [Client.invoke_async documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.47/reference/services/lambda.html#Lambda.Client.invoke_async)
         """
 
     def list_aliases(
@@ -380,7 +383,7 @@ class LambdaClient:
         MaxItems: int = None,
     ) -> ListAliasesResponseTypeDef:
         """
-        [Client.list_aliases documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/lambda.html#Lambda.Client.list_aliases)
+        [Client.list_aliases documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.47/reference/services/lambda.html#Lambda.Client.list_aliases)
         """
 
     def list_event_source_mappings(
@@ -391,14 +394,14 @@ class LambdaClient:
         MaxItems: int = None,
     ) -> ListEventSourceMappingsResponseTypeDef:
         """
-        [Client.list_event_source_mappings documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/lambda.html#Lambda.Client.list_event_source_mappings)
+        [Client.list_event_source_mappings documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.47/reference/services/lambda.html#Lambda.Client.list_event_source_mappings)
         """
 
     def list_function_event_invoke_configs(
         self, FunctionName: str, Marker: str = None, MaxItems: int = None
     ) -> ListFunctionEventInvokeConfigsResponseTypeDef:
         """
-        [Client.list_function_event_invoke_configs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/lambda.html#Lambda.Client.list_function_event_invoke_configs)
+        [Client.list_function_event_invoke_configs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.47/reference/services/lambda.html#Lambda.Client.list_function_event_invoke_configs)
         """
 
     def list_functions(
@@ -409,7 +412,7 @@ class LambdaClient:
         MaxItems: int = None,
     ) -> ListFunctionsResponseTypeDef:
         """
-        [Client.list_functions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/lambda.html#Lambda.Client.list_functions)
+        [Client.list_functions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.47/reference/services/lambda.html#Lambda.Client.list_functions)
         """
 
     def list_layer_versions(
@@ -423,6 +426,7 @@ class LambdaClient:
             "nodejs10.x",
             "nodejs12.x",
             "java8",
+            "java8.al2",
             "java11",
             "python2.7",
             "python3.6",
@@ -437,12 +441,13 @@ class LambdaClient:
             "ruby2.5",
             "ruby2.7",
             "provided",
+            "provided.al2",
         ] = None,
         Marker: str = None,
         MaxItems: int = None,
     ) -> ListLayerVersionsResponseTypeDef:
         """
-        [Client.list_layer_versions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/lambda.html#Lambda.Client.list_layer_versions)
+        [Client.list_layer_versions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.47/reference/services/lambda.html#Lambda.Client.list_layer_versions)
         """
 
     def list_layers(
@@ -455,6 +460,7 @@ class LambdaClient:
             "nodejs10.x",
             "nodejs12.x",
             "java8",
+            "java8.al2",
             "java11",
             "python2.7",
             "python3.6",
@@ -469,31 +475,32 @@ class LambdaClient:
             "ruby2.5",
             "ruby2.7",
             "provided",
+            "provided.al2",
         ] = None,
         Marker: str = None,
         MaxItems: int = None,
     ) -> ListLayersResponseTypeDef:
         """
-        [Client.list_layers documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/lambda.html#Lambda.Client.list_layers)
+        [Client.list_layers documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.47/reference/services/lambda.html#Lambda.Client.list_layers)
         """
 
     def list_provisioned_concurrency_configs(
         self, FunctionName: str, Marker: str = None, MaxItems: int = None
     ) -> ListProvisionedConcurrencyConfigsResponseTypeDef:
         """
-        [Client.list_provisioned_concurrency_configs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/lambda.html#Lambda.Client.list_provisioned_concurrency_configs)
+        [Client.list_provisioned_concurrency_configs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.47/reference/services/lambda.html#Lambda.Client.list_provisioned_concurrency_configs)
         """
 
     def list_tags(self, Resource: str) -> ListTagsResponseTypeDef:
         """
-        [Client.list_tags documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/lambda.html#Lambda.Client.list_tags)
+        [Client.list_tags documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.47/reference/services/lambda.html#Lambda.Client.list_tags)
         """
 
     def list_versions_by_function(
         self, FunctionName: str, Marker: str = None, MaxItems: int = None
     ) -> ListVersionsByFunctionResponseTypeDef:
         """
-        [Client.list_versions_by_function documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/lambda.html#Lambda.Client.list_versions_by_function)
+        [Client.list_versions_by_function documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.47/reference/services/lambda.html#Lambda.Client.list_versions_by_function)
         """
 
     def publish_layer_version(
@@ -510,6 +517,7 @@ class LambdaClient:
                 "nodejs10.x",
                 "nodejs12.x",
                 "java8",
+                "java8.al2",
                 "java11",
                 "python2.7",
                 "python3.6",
@@ -524,12 +532,13 @@ class LambdaClient:
                 "ruby2.5",
                 "ruby2.7",
                 "provided",
+                "provided.al2",
             ]
         ] = None,
         LicenseInfo: str = None,
     ) -> PublishLayerVersionResponseTypeDef:
         """
-        [Client.publish_layer_version documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/lambda.html#Lambda.Client.publish_layer_version)
+        [Client.publish_layer_version documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.47/reference/services/lambda.html#Lambda.Client.publish_layer_version)
         """
 
     def publish_version(
@@ -540,14 +549,14 @@ class LambdaClient:
         RevisionId: str = None,
     ) -> "FunctionConfigurationTypeDef":
         """
-        [Client.publish_version documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/lambda.html#Lambda.Client.publish_version)
+        [Client.publish_version documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.47/reference/services/lambda.html#Lambda.Client.publish_version)
         """
 
     def put_function_concurrency(
         self, FunctionName: str, ReservedConcurrentExecutions: int
     ) -> "ConcurrencyTypeDef":
         """
-        [Client.put_function_concurrency documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/lambda.html#Lambda.Client.put_function_concurrency)
+        [Client.put_function_concurrency documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.47/reference/services/lambda.html#Lambda.Client.put_function_concurrency)
         """
 
     def put_function_event_invoke_config(
@@ -559,38 +568,38 @@ class LambdaClient:
         DestinationConfig: "DestinationConfigTypeDef" = None,
     ) -> "FunctionEventInvokeConfigTypeDef":
         """
-        [Client.put_function_event_invoke_config documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/lambda.html#Lambda.Client.put_function_event_invoke_config)
+        [Client.put_function_event_invoke_config documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.47/reference/services/lambda.html#Lambda.Client.put_function_event_invoke_config)
         """
 
     def put_provisioned_concurrency_config(
         self, FunctionName: str, Qualifier: str, ProvisionedConcurrentExecutions: int
     ) -> PutProvisionedConcurrencyConfigResponseTypeDef:
         """
-        [Client.put_provisioned_concurrency_config documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/lambda.html#Lambda.Client.put_provisioned_concurrency_config)
+        [Client.put_provisioned_concurrency_config documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.47/reference/services/lambda.html#Lambda.Client.put_provisioned_concurrency_config)
         """
 
     def remove_layer_version_permission(
         self, LayerName: str, VersionNumber: int, StatementId: str, RevisionId: str = None
     ) -> None:
         """
-        [Client.remove_layer_version_permission documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/lambda.html#Lambda.Client.remove_layer_version_permission)
+        [Client.remove_layer_version_permission documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.47/reference/services/lambda.html#Lambda.Client.remove_layer_version_permission)
         """
 
     def remove_permission(
         self, FunctionName: str, StatementId: str, Qualifier: str = None, RevisionId: str = None
     ) -> None:
         """
-        [Client.remove_permission documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/lambda.html#Lambda.Client.remove_permission)
+        [Client.remove_permission documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.47/reference/services/lambda.html#Lambda.Client.remove_permission)
         """
 
     def tag_resource(self, Resource: str, Tags: Dict[str, str]) -> None:
         """
-        [Client.tag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/lambda.html#Lambda.Client.tag_resource)
+        [Client.tag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.47/reference/services/lambda.html#Lambda.Client.tag_resource)
         """
 
     def untag_resource(self, Resource: str, TagKeys: List[str]) -> None:
         """
-        [Client.untag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/lambda.html#Lambda.Client.untag_resource)
+        [Client.untag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.47/reference/services/lambda.html#Lambda.Client.untag_resource)
         """
 
     def update_alias(
@@ -603,7 +612,7 @@ class LambdaClient:
         RevisionId: str = None,
     ) -> "AliasConfigurationTypeDef":
         """
-        [Client.update_alias documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/lambda.html#Lambda.Client.update_alias)
+        [Client.update_alias documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.47/reference/services/lambda.html#Lambda.Client.update_alias)
         """
 
     def update_event_source_mapping(
@@ -620,7 +629,7 @@ class LambdaClient:
         ParallelizationFactor: int = None,
     ) -> "EventSourceMappingConfigurationTypeDef":
         """
-        [Client.update_event_source_mapping documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/lambda.html#Lambda.Client.update_event_source_mapping)
+        [Client.update_event_source_mapping documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.47/reference/services/lambda.html#Lambda.Client.update_event_source_mapping)
         """
 
     def update_function_code(
@@ -635,7 +644,7 @@ class LambdaClient:
         RevisionId: str = None,
     ) -> "FunctionConfigurationTypeDef":
         """
-        [Client.update_function_code documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/lambda.html#Lambda.Client.update_function_code)
+        [Client.update_function_code documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.47/reference/services/lambda.html#Lambda.Client.update_function_code)
         """
 
     def update_function_configuration(
@@ -656,6 +665,7 @@ class LambdaClient:
             "nodejs10.x",
             "nodejs12.x",
             "java8",
+            "java8.al2",
             "java11",
             "python2.7",
             "python3.6",
@@ -670,6 +680,7 @@ class LambdaClient:
             "ruby2.5",
             "ruby2.7",
             "provided",
+            "provided.al2",
         ] = None,
         DeadLetterConfig: "DeadLetterConfigTypeDef" = None,
         KMSKeyArn: str = None,
@@ -679,7 +690,7 @@ class LambdaClient:
         FileSystemConfigs: List["FileSystemConfigTypeDef"] = None,
     ) -> "FunctionConfigurationTypeDef":
         """
-        [Client.update_function_configuration documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/lambda.html#Lambda.Client.update_function_configuration)
+        [Client.update_function_configuration documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.47/reference/services/lambda.html#Lambda.Client.update_function_configuration)
         """
 
     def update_function_event_invoke_config(
@@ -691,13 +702,13 @@ class LambdaClient:
         DestinationConfig: "DestinationConfigTypeDef" = None,
     ) -> "FunctionEventInvokeConfigTypeDef":
         """
-        [Client.update_function_event_invoke_config documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/lambda.html#Lambda.Client.update_function_event_invoke_config)
+        [Client.update_function_event_invoke_config documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.47/reference/services/lambda.html#Lambda.Client.update_function_event_invoke_config)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_aliases"]) -> ListAliasesPaginator:
         """
-        [Paginator.ListAliases documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/lambda.html#Lambda.Paginator.ListAliases)
+        [Paginator.ListAliases documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.47/reference/services/lambda.html#Lambda.Paginator.ListAliases)
         """
 
     @overload
@@ -705,7 +716,7 @@ class LambdaClient:
         self, operation_name: Literal["list_event_source_mappings"]
     ) -> ListEventSourceMappingsPaginator:
         """
-        [Paginator.ListEventSourceMappings documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/lambda.html#Lambda.Paginator.ListEventSourceMappings)
+        [Paginator.ListEventSourceMappings documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.47/reference/services/lambda.html#Lambda.Paginator.ListEventSourceMappings)
         """
 
     @overload
@@ -713,13 +724,13 @@ class LambdaClient:
         self, operation_name: Literal["list_function_event_invoke_configs"]
     ) -> ListFunctionEventInvokeConfigsPaginator:
         """
-        [Paginator.ListFunctionEventInvokeConfigs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/lambda.html#Lambda.Paginator.ListFunctionEventInvokeConfigs)
+        [Paginator.ListFunctionEventInvokeConfigs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.47/reference/services/lambda.html#Lambda.Paginator.ListFunctionEventInvokeConfigs)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_functions"]) -> ListFunctionsPaginator:
         """
-        [Paginator.ListFunctions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/lambda.html#Lambda.Paginator.ListFunctions)
+        [Paginator.ListFunctions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.47/reference/services/lambda.html#Lambda.Paginator.ListFunctions)
         """
 
     @overload
@@ -727,13 +738,13 @@ class LambdaClient:
         self, operation_name: Literal["list_layer_versions"]
     ) -> ListLayerVersionsPaginator:
         """
-        [Paginator.ListLayerVersions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/lambda.html#Lambda.Paginator.ListLayerVersions)
+        [Paginator.ListLayerVersions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.47/reference/services/lambda.html#Lambda.Paginator.ListLayerVersions)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_layers"]) -> ListLayersPaginator:
         """
-        [Paginator.ListLayers documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/lambda.html#Lambda.Paginator.ListLayers)
+        [Paginator.ListLayers documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.47/reference/services/lambda.html#Lambda.Paginator.ListLayers)
         """
 
     @overload
@@ -741,7 +752,7 @@ class LambdaClient:
         self, operation_name: Literal["list_provisioned_concurrency_configs"]
     ) -> ListProvisionedConcurrencyConfigsPaginator:
         """
-        [Paginator.ListProvisionedConcurrencyConfigs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/lambda.html#Lambda.Paginator.ListProvisionedConcurrencyConfigs)
+        [Paginator.ListProvisionedConcurrencyConfigs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.47/reference/services/lambda.html#Lambda.Paginator.ListProvisionedConcurrencyConfigs)
         """
 
     @overload
@@ -749,7 +760,7 @@ class LambdaClient:
         self, operation_name: Literal["list_versions_by_function"]
     ) -> ListVersionsByFunctionPaginator:
         """
-        [Paginator.ListVersionsByFunction documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/lambda.html#Lambda.Paginator.ListVersionsByFunction)
+        [Paginator.ListVersionsByFunction documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.47/reference/services/lambda.html#Lambda.Paginator.ListVersionsByFunction)
         """
 
     def get_paginator(self, operation_name: str) -> Boto3Paginator:
@@ -758,19 +769,19 @@ class LambdaClient:
     @overload
     def get_waiter(self, waiter_name: Literal["function_active"]) -> FunctionActiveWaiter:
         """
-        [Waiter.FunctionActive documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/lambda.html#Lambda.Waiter.FunctionActive)
+        [Waiter.FunctionActive documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.47/reference/services/lambda.html#Lambda.Waiter.FunctionActive)
         """
 
     @overload
     def get_waiter(self, waiter_name: Literal["function_exists"]) -> FunctionExistsWaiter:
         """
-        [Waiter.FunctionExists documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/lambda.html#Lambda.Waiter.FunctionExists)
+        [Waiter.FunctionExists documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.47/reference/services/lambda.html#Lambda.Waiter.FunctionExists)
         """
 
     @overload
     def get_waiter(self, waiter_name: Literal["function_updated"]) -> FunctionUpdatedWaiter:
         """
-        [Waiter.FunctionUpdated documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/lambda.html#Lambda.Waiter.FunctionUpdated)
+        [Waiter.FunctionUpdated documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.47/reference/services/lambda.html#Lambda.Waiter.FunctionUpdated)
         """
 
     def get_waiter(self, waiter_name: str) -> Boto3Waiter:
