@@ -148,6 +148,7 @@ EventSourceMappingConfigurationTypeDef = TypedDict(
         "State": str,
         "StateTransitionReason": str,
         "DestinationConfig": "DestinationConfigTypeDef",
+        "Topics": List[str],
         "MaximumRecordAgeInSeconds": int,
         "BisectBatchOnFunctionError": bool,
         "MaximumRetryAttempts": int,
@@ -174,6 +175,7 @@ FunctionConfigurationTypeDef = TypedDict(
             "nodejs10.x",
             "nodejs12.x",
             "java8",
+            "java8.al2",
             "java11",
             "python2.7",
             "python3.6",
@@ -188,6 +190,7 @@ FunctionConfigurationTypeDef = TypedDict(
             "ruby2.5",
             "ruby2.7",
             "provided",
+            "provided.al2",
         ],
         "Role": str,
         "Handler": str,
@@ -272,6 +275,7 @@ LayerVersionsListItemTypeDef = TypedDict(
                 "nodejs10.x",
                 "nodejs12.x",
                 "java8",
+                "java8.al2",
                 "java11",
                 "python2.7",
                 "python3.6",
@@ -286,6 +290,7 @@ LayerVersionsListItemTypeDef = TypedDict(
                 "ruby2.5",
                 "ruby2.7",
                 "provided",
+                "provided.al2",
             ]
         ],
         "LicenseInfo": str,
@@ -386,6 +391,7 @@ GetLayerVersionResponseTypeDef = TypedDict(
                 "nodejs10.x",
                 "nodejs12.x",
                 "java8",
+                "java8.al2",
                 "java11",
                 "python2.7",
                 "python3.6",
@@ -400,6 +406,7 @@ GetLayerVersionResponseTypeDef = TypedDict(
                 "ruby2.5",
                 "ruby2.7",
                 "provided",
+                "provided.al2",
             ]
         ],
         "LicenseInfo": str,
@@ -521,6 +528,7 @@ PublishLayerVersionResponseTypeDef = TypedDict(
                 "nodejs10.x",
                 "nodejs12.x",
                 "java8",
+                "java8.al2",
                 "java11",
                 "python2.7",
                 "python3.6",
@@ -535,6 +543,7 @@ PublishLayerVersionResponseTypeDef = TypedDict(
                 "ruby2.5",
                 "ruby2.7",
                 "provided",
+                "provided.al2",
             ]
         ],
         "LicenseInfo": str,
